import{Q as s,aQ as m,c as n,aj as e,Z as l,B as c,S as u,a4 as f}from"./index-DdI--Yet.js";import{I as h}from"./ItemsListing-DWzn5l67.js";import"./MediaItemThumb-DHcqTVjl.js";import"./ProviderIcon.vue_vue_type_style_index_0_lang-D41gG9IS.js";import"./VChip-BBcriFso.js";import"./VBtn-g6NhQ7fK.js";import"./_plugin-vue_export-helper-DlAUqK2U.js";import"./ListItem-BK1DMsnV.js";import"./VCheckbox-B4YfxJ0R.js";import"./VCheckboxBtn-BWCQ3DqN.js";import"./PanelviewItemCompact-kTIN1Q1A.js";import"./VSpacer-DDLLNEUh.js";/* empty css              */import"./Container-B4zACZDu.js";import"./VContainer-BtdP8B7E.js";import"./Toolbar-BGUFqu6B.js";import"./VToolbar-DRvSLcNG.js";import"./VTextField-CkYsZnxG.js";import"./VInfiniteScroll-B6R5NfAO.js";import"./layout-CiO1VcK1.js";import"./VRow-VEN0m6ZM.js";import"./VVirtualScroll-D10a-qpl.js";import"./VAlert-CIZAmx66.js";const F=s({__name:"BrowseView",props:{path:{}},setup(a){const t=a,{t:o}=m(),i=n(()=>!t.path||t.path=="root"?o("browse"):e("bp6")?o("browse")+" | "+t.path:e("bp3")?t.path:o("browse")),p=async function(r){return await f.browse(t.path)};return(r,w)=>(u(),l("section",null,[c(h,{itemtype:"browse","show-provider":!1,"show-library":!1,"show-favorites-only-filter":!1,"show-track-number":!1,"load-items":p,"sort-keys":["original","name","name_desc"],title:i.value,path:r.path,"allow-key-hooks":!0,icon:"mdi-folder-outline"},null,8,["title","path"])]))}});export{F as default};
